@@ -3,20 +3,29 @@
 # SPDX-License-Identifier: MIT
 
 from .to_ngff_image import to_ngff_image
+from .from_ngff_zarr import from_ngff_zarr
 from .itk_image_to_ngff_image import itk_image_to_ngff_image
+from .detect_cli_input_backend import detect_cli_input_backend, ConversionBackend
+from .cli_input_to_ngff_image import cli_input_to_ngff_image
 from .__about__ import __version__
 from .ngff_image import NgffImage
 from .to_multiscales import to_multiscales, Multiscales
 from .to_ngff_zarr import to_ngff_zarr
 from .methods import Methods
+from .config import config
 
 __all__ = [
     "__version__",
+    "config",
     "NgffImage",
     "to_ngff_image",
+    "from_ngff_image",
     "itk_image_to_ngff_image",
     "to_multiscales",
     "Multiscales",
     "Methods",
     "to_ngff_zarr",
+    "detect_cli_input_backend",
+    "ConversionBackend",
+    "cli_input_to_ngff_image",
 ]
